@@ -2,7 +2,7 @@ use criterion::{criterion_group, criterion_main, Criterion};
 use pprof::criterion::{Output, PProfProfiler};
 
 use genetic_algorithm::evolve::prelude::*;
-use genetic_algorithm::fitness::FitnessSimpleCount;
+use genetic_algorithm::fitness::placeholders::CountTrue;
 use rand::prelude::*;
 use rand::rngs::SmallRng;
 
@@ -30,7 +30,7 @@ fn run() {
         .with_max_stale_generations(1000)
         .with_target_fitness_score(100)
         .with_mutate(MutateOnce(0.2))
-        .with_fitness(FitnessSimpleCount)
+        .with_fitness(CountTrue)
         .with_crossover(CrossoverAll(true))
         .with_compete(CompeteTournament(4))
         .build()
