@@ -5,6 +5,6 @@ pub use crate::fitness::{Fitness, FitnessOrdering, FitnessValue};
 #[doc(no_inline)]
 pub use crate::genotype::{
     BinaryGenotype, ContinuousGenotype, DiscreteGenotype, Genotype, GenotypeBuilder,
-    MultiContinuousGenotype, MultiDiscreteGenotype, TryFromGenotypeBuilderError,
+    MultiContinuousGenotype, MultiDiscreteGenotype, SetGenotype, TryFromGenotypeBuilderError,
     UniqueDiscreteGenotype,
 };
