@@ -5,6 +5,7 @@ mod continuous;
 mod discrete;
 mod multi_continuous;
 mod multi_discrete;
+mod set;
 mod unique_discrete;
 
 pub use self::binary::Binary as BinaryGenotype;
@@ -15,11 +16,12 @@ pub use self::continuous::Continuous as ContinuousGenotype;
 pub use self::discrete::Discrete as DiscreteGenotype;
 pub use self::multi_continuous::MultiContinuous as MultiContinuousGenotype;
 pub use self::multi_discrete::MultiDiscrete as MultiDiscreteGenotype;
+pub use self::set::Set as SetGenotype;
 pub use self::unique_discrete::UniqueDiscrete as UniqueDiscreteGenotype;
 
 use crate::chromosome::Chromosome;
-use crate::population::Population;
 use itertools::Itertools;
+use num::BigUint;
 use rand::prelude::*;
 use std::fmt;
 
@@ -48,17 +50,21 @@ pub trait Genotype: Clone + fmt::Debug + fmt::Display + TryFrom<GenotypeBuilder<
 /// Not all genotypes are permutable, only countable ones (e.g. continuous genotypes cannot be permutated).
 pub trait PermutableGenotype: Genotype {
     fn gene_values(&self) -> Vec<Self::Gene>;
-    /// the full population with all possible gene combinations for [Permutate](crate::permutate::Permutate)
-    fn population_factory(&self) -> Population<Self> {
-        let chromosomes = (0..self.gene_size())
-            .map(|_| self.gene_values())
-            .multi_cartesian_product()
-            .map(|genes| Chromosome::new(genes))
-            .collect();
 
-        Population::new(chromosomes)
+    /// chromosome iterator for the all possible gene combinations for [Permutate](crate::permutate::Permutate)
+    fn chromosome_permutations_into_iter<'a>(
+        &'a self,
+    ) -> Box<dyn Iterator<Item = Chromosome<Self>> + 'a> {
+        Box::new(
+            (0..self.gene_size())
+                .map(|_| self.gene_values())
+                .multi_cartesian_product()
+                .map(|genes| Chromosome::new(genes)),
+        )
     }
-    fn population_factory_size(&self) -> usize {
-        self.gene_values().len().pow(self.gene_size() as u32)
+
+    /// chromosome iterator size for the all possible gene combinations for [Permutate](crate::permutate::Permutate)
+    fn chromosome_permutations_size(&self) -> BigUint {
+        BigUint::from(self.gene_values().len()).pow(self.gene_size() as u32)
     }
 }
