@@ -48,7 +48,7 @@ impl TryFrom<Builder<Self>> for MultiContinuous {
             ))
         } else if builder.gene_ranges.as_ref().map(|o| o.is_empty()).unwrap() {
             Err(TryFromBuilderError(
-                "UniqueDiscreteGenotype requires non-empty gene_ranges",
+                "MultiContinuousGenotype requires non-empty gene_ranges",
             ))
         } else {
             let gene_ranges = builder.gene_ranges.unwrap();
@@ -100,6 +100,7 @@ impl fmt::Display for MultiContinuous {
         writeln!(f, "genotype:")?;
         writeln!(f, "  gene_size: {}", self.gene_size)?;
         writeln!(f, "  gene_ranges: {:?}\n", self.gene_ranges)?;
+        writeln!(f, "  chromosome_permutations_size: uncountable")?;
         writeln!(f, "  seed_genes: {:?}", self.seed_genes)
     }
 }
