@@ -1,8 +1,8 @@
 use super::builder::{Builder, TryFromBuilderError};
 use super::{Genotype, PermutableGenotype};
 use crate::chromosome::Chromosome;
-use crate::population::Population;
 use itertools::Itertools;
+use num::BigUint;
 use rand::distributions::{Distribution, Uniform, WeightedIndex};
 use rand::prelude::*;
 use std::fmt;
@@ -101,7 +101,7 @@ impl<T: Clone + std::fmt::Debug> TryFrom<Builder<Self>> for MultiDiscrete<T> {
             .unwrap()
         {
             Err(TryFromBuilderError(
-                "UniqueDiscreteGenotype requires non-empty gene_multi_values",
+                "MultiDiscreteGenotype requires non-empty gene_multi_values",
             ))
         } else {
             let gene_multi_values = builder.gene_multi_values.unwrap();
@@ -156,19 +156,24 @@ impl<T: Clone + std::fmt::Debug> PermutableGenotype for MultiDiscrete<T> {
     fn gene_values(&self) -> Vec<Self::Gene> {
         vec![]
     }
-    fn population_factory(&self) -> Population<Self> {
-        let chromosomes = self
-            .gene_multi_values
-            .iter()
-            .map(|gene_values| gene_values.clone())
-            .multi_cartesian_product()
-            .map(Chromosome::new)
-            .collect();
 
-        Population::new(chromosomes)
+    fn chromosome_permutations_into_iter<'a>(
+        &'a self,
+    ) -> Box<dyn Iterator<Item = Chromosome<Self>> + 'a> {
+        Box::new(
+            self.gene_multi_values
+                .clone()
+                .into_iter()
+                .multi_cartesian_product()
+                .map(Chromosome::new),
+        )
     }
-    fn population_factory_size(&self) -> usize {
-        self.gene_value_sizes.iter().product()
+
+    fn chromosome_permutations_size(&self) -> BigUint {
+        self.gene_value_sizes
+            .iter()
+            .map(|v| BigUint::from(*v))
+            .product()
     }
 }
 
@@ -178,6 +183,11 @@ impl<T: Clone + std::fmt::Debug> fmt::Display for MultiDiscrete<T> {
         writeln!(f, "  gene_size: {}\n", self.gene_size)?;
         writeln!(f, "  gene_value_sizes: {:?}", self.gene_value_sizes)?;
         writeln!(f, "  gene_multi_values: {:?}", self.gene_multi_values)?;
+        writeln!(
+            f,
+            "  chromosome_permutations_size: {}",
+            self.chromosome_permutations_size()
+        )?;
         writeln!(f, "  seed_genes: {:?}", self.seed_genes)
     }
 }
