@@ -1,9 +1,9 @@
 use super::builder::{Builder, TryFromBuilderError};
 use super::{Genotype, PermutableGenotype};
 use crate::chromosome::Chromosome;
-use crate::population::Population;
 use factorial::Factorial;
 use itertools::Itertools;
+use num::BigUint;
 use rand::distributions::{Distribution, Uniform};
 use rand::prelude::*;
 use std::fmt;
@@ -103,18 +103,21 @@ impl<T: Clone + std::fmt::Debug> PermutableGenotype for UniqueDiscrete<T> {
     fn gene_values(&self) -> Vec<Self::Gene> {
         self.gene_values.clone()
     }
-    fn population_factory(&self) -> Population<Self> {
-        let chromosomes = self
-            .gene_values()
-            .iter()
-            .permutations(self.gene_size())
-            .map(|genes| Chromosome::new(genes.into_iter().cloned().collect()))
-            .collect();
 
-        Population::new(chromosomes)
+    fn chromosome_permutations_into_iter<'a>(
+        &'a self,
+    ) -> Box<dyn Iterator<Item = Chromosome<Self>> + 'a> {
+        Box::new(
+            self.gene_values
+                .clone()
+                .into_iter()
+                .permutations(self.gene_size())
+                .map(|genes| Chromosome::new(genes)),
+        )
     }
-    fn population_factory_size(&self) -> usize {
-        self.gene_values().len().factorial()
+
+    fn chromosome_permutations_size(&self) -> BigUint {
+        BigUint::from(self.gene_values.len()).factorial()
     }
 }
 
@@ -122,6 +125,11 @@ impl<T: Clone + std::fmt::Debug> fmt::Display for UniqueDiscrete<T> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         writeln!(f, "genotype:")?;
         writeln!(f, "  gene_values: {:?}", self.gene_values)?;
+        writeln!(
+            f,
+            "  chromosome_permutations_size: {}",
+            self.chromosome_permutations_size()
+        )?;
         writeln!(f, "  seed_genes: {:?}", self.seed_genes)
     }
 }
