@@ -9,18 +9,19 @@ pub use self::builder::{
 use crate::chromosome::Chromosome;
 use crate::fitness::{Fitness, FitnessOrdering, FitnessValue};
 use crate::genotype::PermutableGenotype;
-use crate::population::Population;
+use num::BigUint;
 use std::fmt;
 
-/// All possible combinations of genes are instantiated as chromosomes in the population.
+/// All possible combinations of genes are iterated over as chromosomes.
 /// The fitness is calculated for each chromosome and the best is taken.
+/// For efficiency reasons the full population is never instantiated as a whole.
 ///
 /// See [PermutateBuilder] for initialization options.
 ///
 /// Example:
 /// ```
 /// use genetic_algorithm::permutate::prelude::*;
-/// use genetic_algorithm::fitness::FitnessSimpleCount;
+/// use genetic_algorithm::fitness::placeholders::CountTrue;
 ///
 /// // the search space
 /// let genotype = BinaryGenotype::builder() // boolean genes
@@ -31,7 +32,7 @@ use std::fmt;
 /// // the search strategy
 /// let permutate = Permutate::builder()
 ///     .with_genotype(genotype)
-///     .with_fitness(FitnessSimpleCount)                 // count the number of true values in the chromosomes
+///     .with_fitness(CountTrue)                          // count the number of true values in the chromosomes
 ///     .with_fitness_ordering(FitnessOrdering::Minimize) // aim for the least true values
 ///     .build()
 ///     .unwrap()
@@ -48,7 +49,7 @@ pub struct Permutate<G: PermutableGenotype, F: Fitness<Genotype = G>> {
     pub fitness_ordering: FitnessOrdering,
 
     pub best_chromosome: Option<Chromosome<G>>,
-    pub population: Population<G>,
+    pub population_size: BigUint,
 }
 
 impl<G: PermutableGenotype, F: Fitness<Genotype = G>> Permutate<G, F> {
@@ -57,17 +58,45 @@ impl<G: PermutableGenotype, F: Fitness<Genotype = G>> Permutate<G, F> {
     }
 
     pub fn call(mut self) -> Self {
-        self.population = self.genotype.population_factory();
-        self.population = self.fitness.call_for_population(self.population);
-        self.update_best_chromosome();
+        for mut chromosome in self.genotype.clone().chromosome_permutations_into_iter() {
+            self.fitness.call_for_chromosome(&mut chromosome);
+            self.update_best_chromosome(&chromosome);
+        }
         self
     }
 
-    fn update_best_chromosome(&mut self) {
-        self.best_chromosome = self
-            .population
-            .best_chromosome(self.fitness_ordering)
-            .cloned();
+    fn update_best_chromosome(&mut self, contending_best_chromosome: &Chromosome<G>) {
+        match self.best_chromosome.as_ref() {
+            None => {
+                self.best_chromosome = Some(contending_best_chromosome.clone());
+            }
+            Some(current_best_chromosome) => {
+                match (
+                    current_best_chromosome.fitness_score,
+                    contending_best_chromosome.fitness_score,
+                ) {
+                    (None, None) => {}
+                    (Some(_), None) => {}
+                    (None, Some(_)) => {
+                        self.best_chromosome = Some(contending_best_chromosome.clone());
+                    }
+                    (Some(current_fitness_score), Some(contending_fitness_score)) => {
+                        match self.fitness_ordering {
+                            FitnessOrdering::Maximize => {
+                                if contending_fitness_score > current_fitness_score {
+                                    self.best_chromosome = Some(contending_best_chromosome.clone());
+                                }
+                            }
+                            FitnessOrdering::Minimize => {
+                                if contending_fitness_score < current_fitness_score {
+                                    self.best_chromosome = Some(contending_best_chromosome.clone());
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+        }
     }
 
     fn best_fitness_score(&self) -> Option<FitnessValue> {
@@ -88,14 +117,17 @@ impl<G: PermutableGenotype, F: Fitness<Genotype = G>> TryFrom<PermutateBuilder<G
         } else if builder.fitness.is_none() {
             Err(TryFromPermutateBuilderError("Permutate requires a Fitness"))
         } else {
+            let genotype = builder.genotype.unwrap();
+            let population_size = genotype.chromosome_permutations_size();
+
             Ok(Self {
-                genotype: builder.genotype.unwrap(),
+                genotype: genotype,
                 fitness: builder.fitness.unwrap(),
 
                 fitness_ordering: builder.fitness_ordering,
 
                 best_chromosome: None,
-                population: Population::new_empty(),
+                population_size: population_size,
             })
         }
     }
@@ -107,7 +139,7 @@ impl<G: PermutableGenotype, F: Fitness<Genotype = G>> fmt::Display for Permutate
         writeln!(f, "  genotype: {:?}", self.genotype)?;
         writeln!(f, "  fitness: {:?}", self.fitness)?;
 
-        writeln!(f, "  population size: {:?}", self.population.size())?;
+        writeln!(f, "  population_size: {}", self.population_size)?;
         writeln!(f, "  fitness_ordering: {:?}", self.fitness_ordering)?;
 
         writeln!(f, "  best fitness score: {:?}", self.best_fitness_score())?;
