@@ -1,8 +1,12 @@
+#[doc(no_inline)]
 pub use crate::chromosome::{Chromosome, GenesKey};
+#[doc(no_inline)]
 pub use crate::fitness::{Fitness, FitnessOrdering, FitnessValue};
+#[doc(no_inline)]
 pub use crate::genotype::{
     BinaryGenotype, ContinuousGenotype, DiscreteGenotype, Genotype, GenotypeBuilder,
-    MultiContinuousGenotype, MultiDiscreteGenotype, TryFromGenotypeBuilderError,
+    MultiContinuousGenotype, MultiDiscreteGenotype, SetGenotype, TryFromGenotypeBuilderError,
     UniqueDiscreteGenotype,
 };
+#[doc(no_inline)]
 pub use crate::permutate::{Permutate, PermutateBuilder, TryFromPermutateBuilderError};
