@@ -15,6 +15,21 @@ pub fn chromosome_with_fitness_score<T: Genotype>(
     (chromosome.genes.clone(), chromosome.fitness_score)
 }
 
+#[allow(dead_code)]
+pub fn chromosomes<T: Genotype>(chromosomes: &Vec<Chromosome<T>>) -> Vec<Vec<T::Gene>> {
+    chromosomes.iter().map(|c| chromosome(&c)).collect()
+}
+
+#[allow(dead_code)]
+pub fn chromosomes_with_fitness_score<T: Genotype>(
+    chromosomes: &Vec<Chromosome<T>>,
+) -> Vec<(Vec<T::Gene>, Option<FitnessValue>)> {
+    chromosomes
+        .iter()
+        .map(|c| chromosome_with_fitness_score(&c))
+        .collect()
+}
+
 #[allow(dead_code)]
 pub fn population<T: Genotype>(population: &Population<T>) -> Vec<Vec<T::Gene>> {
     population
